@@ -14,6 +14,7 @@ class HourGroupAdmin(admin.ModelAdmin):
     list_display = ('name',)
     list_filter = ('activities',)
     ordering = ('order', 'name')
+    filter_horizontal = ('activities',)
 admin.site.register(timepiece.HourGroup, HourGroupAdmin)
 
 
@@ -21,6 +22,7 @@ class ActivityGroupAdmin(admin.ModelAdmin):
     model = timepiece.ActivityGroup
     list_display = ('name',)
     list_filter = ('activities',)
+    filter_horizontal = ('activities',)
 admin.site.register(timepiece.ActivityGroup, ActivityGroupAdmin)
 
 
@@ -30,7 +32,8 @@ admin.site.register(timepiece.RelationshipType, RelationshipTypeAdmin)
 
 
 class BusinessAdmin(admin.ModelAdmin):
-    pass
+    list_display = ['name', 'short_name']
+    search_fields = ['name', 'short_name']
 admin.site.register(timepiece.Business, BusinessAdmin)
 
 
@@ -76,85 +79,50 @@ class ContractAssignmentInline(admin.TabularInline):
         return qs.select_related()
 
 
-class ContractMilestoneInline(admin.TabularInline):
-    model = timepiece.ContractMilestone
-
+class ContractHourInline(admin.TabularInline):
+    model = timepiece.ContractHour
 
 class ProjectContractAdmin(admin.ModelAdmin):
     model = timepiece.ProjectContract
-    list_display = ('_project', 'start_date', 'end_date', 'status',
-                    'num_hours', 'hours_assigned', 'hours_unassigned',
-                    'hours_worked')
-    ordering = ('-end_date',)
-    inlines = (ContractAssignmentInline, ContractMilestoneInline)
-    list_filter = ('status',)
-    raw_id_fields = ('project',)
+    list_display = ('name', 'start_date', 'end_date', 'status',
+                    'contracted_hours', 'pending_hours',
+                    'hours_assigned', 'hours_unassigned',
+                    'hours_worked',
+                    'type')
+    inlines = (ContractAssignmentInline, ContractHourInline)
+    list_filter = ('status', 'type')
+    filter_horizontal = ('projects',)
     list_per_page = 20
-
-    def _project(self, obj):
-        return obj.project.name
-    _project.admin_order_field = 'project__name'
-    _project.short_description = 'Project'
+    search_fields = ('name', 'projects__name', 'projects__business__name')
 
     def hours_unassigned(self, obj):
-        return obj.num_hours - obj.hours_assigned
+        return obj.contracted_hours() - obj.hours_assigned
 
 admin.site.register(timepiece.ProjectContract, ProjectContractAdmin)
 
 
-class ProjectContractInline(admin.TabularInline):
-    model = timepiece.ProjectContract
-    extra = 0
-
-
 class ProjectAdmin(admin.ModelAdmin):
-    model = timepiece.Project
     raw_id_fields = ('business',)
-    list_display = ('name', 'business', 'point_person', 'status', 'type',)
+    list_display = ('name', 'business', 'point_person', 'status', 'type')
     list_filter = ('type', 'status')
-    inlines = (ProjectContractInline,)
     search_fields = ('name', 'business__name', 'point_person__username',
             'point_person__first_name', 'point_person__last_name',
             'description')
 admin.site.register(timepiece.Project, ProjectAdmin)
 
 
-class ContractAssignmentAdmin(admin.ModelAdmin):
-    list_display = ('id', 'contract', 'user', 'start_date',
-                    'end_date', 'min_hours_per_week', 'num_hours', 'worked',
-                    'remaining')
-    list_filter = ('contract',)
-    ordering = ('-start_date',)
-
-    def queryset(self, request):
-        qs = super(ContractAssignmentAdmin, self).queryset(request)
-        return qs.exclude(contract__status='complete')
-
-    def worked(self, obj):
-        hours_worked = float(obj.hours_worked)
-        if obj.num_hours:
-            percent = hours_worked * 100.0 / float(obj.num_hours)
-            return "%.2f (%.2f%%)" % (hours_worked, percent)
-        return ""
-
-    def remaining(self, obj):
-        return "%.2f" % (obj.hours_remaining,)
-
-admin.site.register(timepiece.ContractAssignment, ContractAssignmentAdmin)
-
-
 class LocationAdmin(admin.ModelAdmin):
     list_display = ('id', 'name')
 admin.site.register(timepiece.Location, LocationAdmin)
 
 
 class ProjectHoursAdmin(admin.ModelAdmin):
-    list_display = ('_person', 'project', 'week_start', 'hours', 'published')
+    list_display = ('_user', 'project', 'week_start', 'hours', 'published')
 
-    def _person(self, obj):
-        return obj.user.get_full_name()
-    _person.short_description = 'Person'
-    _person.admin_order_field = 'user__last_name'
+    def _user(self, obj):
+        return obj.user.get_name_or_username()
+    _user.short_description = 'User'
+    _user.admin_order_field = 'user__last_name'
 
 admin.site.register(timepiece.ProjectHours, ProjectHoursAdmin)
 
